[SCM] Samba Shared Repository - branch master updated

Volker Lendecke vlendec at samba.org
Tue Sep 26 19:29:01 UTC 2023


The branch, master has been updated
       via  d7394a90f51 testparm: Allow idmap ranges overlap for idmap_nss
      from  fab08854af3 libsmb: Pass neg contexts through sync smbXcli_negprot_recv()

https://git.samba.org/?p=samba.git;a=shortlog;h=master


- Log -----------------------------------------------------------------
commit d7394a90f51e9a2caac58d280e2ec3331f45a315
Author: Samuel Cabrero <scabrero at samba.org>
Date:   Tue Sep 26 13:01:03 2023 +0200

    testparm: Allow idmap ranges overlap for idmap_nss
    
    Signed-off-by: Samuel Cabrero <scabrero at samba.org>
    Reviewed-by: Volker Lendecke <vl at samba.org>
    
    Autobuild-User(master): Volker Lendecke <vl at samba.org>
    Autobuild-Date(master): Tue Sep 26 19:28:08 UTC 2023 on atb-devel-224

-----------------------------------------------------------------------

Summary of changes:
 source3/utils/testparm.c | 11 ++++++++---
 1 file changed, 8 insertions(+), 3 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/utils/testparm.c b/source3/utils/testparm.c
index 4a19f888632..fd90e8d734a 100644
--- a/source3/utils/testparm.c
+++ b/source3/utils/testparm.c
@@ -229,16 +229,21 @@ static bool do_idmap_check(void)
 
 			if ((c->low >= x->low && c->low <= x->high) ||
 			    (c->high >= x->low && c->high <= x->high)) {
 				/* Allow overlapping ranges for idmap_ad */
 				ok = strequal(c->backend, x->backend);
 				if (ok) {
-					ok = strequal(c->backend, "ad");
+					ok = strequal(c->backend, "ad") ||
+					     strequal(c->backend, "nss");
 					if (ok) {
 						fprintf(stderr,
-							"NOTE: The idmap_ad "
+							"NOTE: The idmap_%s "
 							"range for the domain "
 							"%s overlaps with the "
 							"range of %s.\n\n",
+							c->backend,
 							c->domain_name,
 							x->domain_name);
 						continue;
@@ -229,16 +229,21 @@ static bool do_idmap_check(void)
 			if ((c->low >= x->low && c->low <= x->high) ||
 			    (c->high >= x->low && c->high <= x->high)) {
-				/* Allow overlapping ranges for idmap_ad */
+				/*
+				 * Allow overlapping ranges for idmap_ad
+				 * and idmap_nss
+				 */
 				ok = strequal(c->backend, x->backend);
 				if (ok) {


-- 
Samba Shared Repository



More information about the samba-cvs mailing list